svn commit: r185327 - head/sys/geom/part

Marcel Moolenaar marcel at FreeBSD.org
Tue Nov 25 21:18:27 PST 2008


Author: marcel
Date: Wed Nov 26 05:18:27 2008
New Revision: 185327
URL: http://svn.freebsd.org/changeset/base/185327

Log:
  Allow dumpon to a partition of type FS_UNUSED as well.

Modified:
  head/sys/geom/part/g_part_bsd.c

Modified: head/sys/geom/part/g_part_bsd.c
==============================================================================
--- head/sys/geom/part/g_part_bsd.c	Wed Nov 26 03:48:20 2008	(r185326)
+++ head/sys/geom/part/g_part_bsd.c	Wed Nov 26 05:18:27 2008	(r185327)
@@ -241,9 +241,10 @@ g_part_bsd_dumpto(struct g_part_table *t
 {
 	struct g_part_bsd_entry *entry;
 
 	/* Allow dumping to a swap partition only. */
 	entry = (struct g_part_bsd_entry *)baseentry;
-	return ((entry->part.p_fstype == FS_SWAP) ? 1 : 0);
+	return ((entry->part.p_fstype == FS_UNUSED ||
+	    entry->part.p_fstype == FS_SWAP) ? 1 : 0);
 }
 
 static int
@@ -241,9 +241,10 @@ g_part_bsd_dumpto(struct g_part_table *t
 	struct g_part_bsd_entry *entry;
 
-	/* Allow dumping to a swap partition only. */
+	/* Allow dumping to a swap partition or an unused partition. */
 	entry = (struct g_part_bsd_entry *)baseentry;


More information about the svn-src-head mailing list